#line 1 "quote_fmt_lex.c"

#line 3 "quote_fmt_lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer quote_fmt_create_buffer
#define yy_delete_buffer quote_fmt_delete_buffer
#define yy_scan_buffer quote_fmt_scan_buffer
#define yy_scan_string quote_fmt_scan_string
#define yy_scan_bytes quote_fmt_scan_bytes
#define yy_init_buffer quote_fmt_init_buffer
#define yy_flush_buffer quote_fmt_flush_buffer
#define yy_load_buffer_state quote_fmt_load_buffer_state
#define yy_switch_to_buffer quote_fmt_switch_to_buffer
#define yypush_buffer_state quote_fmtpush_buffer_state
#define yypop_buffer_state quote_fmtpop_buffer_state
#define yyensure_buffer_stack quote_fmtensure_buffer_stack
#define yy_flex_debug quote_fmt_flex_debug
#define yyin quote_fmtin
#define yyleng quote_fmtleng
#define yylex quote_fmtlex
#define yylineno quote_fmtlineno
#define yyout quote_fmtout
#define yyrestart quote_fmtrestart
#define yytext quote_fmttext
#define yywrap quote_fmtwrap
#define yyalloc quote_fmtalloc
#define yyrealloc quote_fmtrealloc
#define yyfree quote_fmtfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define quote_fmt_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer quote_fmt_create_buffer
#endif

#ifdef yy_delete_buffer
#define quote_fmt_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer quote_fmt_delete_buffer
#endif

#ifdef yy_scan_buffer
#define quote_fmt_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer quote_fmt_scan_buffer
#endif

#ifdef yy_scan_string
#define quote_fmt_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string quote_fmt_scan_string
#endif

#ifdef yy_scan_bytes
#define quote_fmt_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes quote_fmt_scan_bytes
#endif

#ifdef yy_init_buffer
#define quote_fmt_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer quote_fmt_init_buffer
#endif

#ifdef yy_flush_buffer
#define quote_fmt_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer quote_fmt_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define quote_fmt_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state quote_fmt_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define quote_fmt_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer quote_fmt_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define quote_fmtpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state quote_fmtpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define quote_fmtpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state quote_fmtpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define quote_fmtensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack quote_fmtensure_buffer_stack
#endif

#ifdef yylex
#define quote_fmtlex_ALREADY_DEFINED
#else
#define yylex quote_fmtlex
#endif

#ifdef yyrestart
#define quote_fmtrestart_ALREADY_DEFINED
#else
#define yyrestart quote_fmtrestart
#endif

#ifdef yylex_init
#define quote_fmtlex_init_ALREADY_DEFINED
#else
#define yylex_init quote_fmtlex_init
#endif

#ifdef yylex_init_extra
#define quote_fmtlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra quote_fmtlex_init_extra
#endif

#ifdef yylex_destroy
#define quote_fmtlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy quote_fmtlex_destroy
#endif

#ifdef yyget_debug
#define quote_fmtget_debug_ALREADY_DEFINED
#else
#define yyget_debug quote_fmtget_debug
#endif

#ifdef yyset_debug
#define quote_fmtset_debug_ALREADY_DEFINED
#else
#define yyset_debug quote_fmtset_debug
#endif

#ifdef yyget_extra
#define quote_fmtget_extra_ALREADY_DEFINED
#else
#define yyget_extra quote_fmtget_extra
#endif

#ifdef yyset_extra
#define quote_fmtset_extra_ALREADY_DEFINED
#else
#define yyset_extra quote_fmtset_extra
#endif

#ifdef yyget_in
#define quote_fmtget_in_ALREADY_DEFINED
#else
#define yyget_in quote_fmtget_in
#endif

#ifdef yyset_in
#define quote_fmtset_in_ALREADY_DEFINED
#else
#define yyset_in quote_fmtset_in
#endif

#ifdef yyget_out
#define quote_fmtget_out_ALREADY_DEFINED
#else
#define yyget_out quote_fmtget_out
#endif

#ifdef yyset_out
#define quote_fmtset_out_ALREADY_DEFINED
#else
#define yyset_out quote_fmtset_out
#endif

#ifdef yyget_leng
#define quote_fmtget_leng_ALREADY_DEFINED
#else
#define yyget_leng quote_fmtget_leng
#endif

#ifdef yyget_text
#define quote_fmtget_text_ALREADY_DEFINED
#else
#define yyget_text quote_fmtget_text
#endif

#ifdef yyget_lineno
#define quote_fmtget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno quote_fmtget_lineno
#endif

#ifdef yyset_lineno
#define quote_fmtset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno quote_fmtset_lineno
#endif

#ifdef yywrap
#define quote_fmtwrap_ALREADY_DEFINED
#else
#define yywrap quote_fmtwrap
#endif

#ifdef yyalloc
#define quote_fmtalloc_ALREADY_DEFINED
#else
#define yyalloc quote_fmtalloc
#endif

#ifdef yyrealloc
#define quote_fmtrealloc_ALREADY_DEFINED
#else
#define yyrealloc quote_fmtrealloc
#endif

#ifdef yyfree
#define quote_fmtfree_ALREADY_DEFINED
#else
#define yyfree quote_fmtfree
#endif

#ifdef yytext
#define quote_fmttext_ALREADY_DEFINED
#else
#define yytext quote_fmttext
#endif

#ifdef yyleng
#define quote_fmtleng_ALREADY_DEFINED
#else
#define yyleng quote_fmtleng
#endif

#ifdef yyin
#define quote_fmtin_ALREADY_DEFINED
#else
#define yyin quote_fmtin
#endif

#ifdef yyout
#define quote_fmtout_ALREADY_DEFINED
#else
#define yyout quote_fmtout
#endif

#ifdef yy_flex_debug
#define quote_fmt_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug quote_fmt_flex_debug
#endif

#ifdef yylineno
#define quote_fmtlineno_ALREADY_DEFINED
#else
#define yylineno quote_fmtlineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 88
#define YY_END_OF_BUFFER 89
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[501] =
    {   0,
        0,    0,    0,    0,    0,    0,   89,   87,   34,   35,
       87,   87,   87,   87,   87,   85,   86,   83,   84,    0,
       62,   65,    0,   66,   60,   61,   68,    0,    0,   67,
       69,   63,   64,    0,   44,   47,    0,   48,   42,   43,
       50,    0,    0,   49,   51,   45,   46,   38,   32,   37,
       33,   36,   34,   40,   39,   41,   82,   81,   78,   80,
       79,    2,    5,    7,    9,   14,   11,   13,   20,   18,
        1,    0,    3,    4,    0,    6,    8,    0,   10,   12,
       21,   15,   16,   17,    0,   74,    0,    0,   70,   71,
       72,   66,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,   64,    0,   56,    0,    0,   52,   53,
       54,   48,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   46,    0,    0,    0,    0,    0,   28,
        0,    0,   22,   23,   24,   25,   26,    3,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   17,   75,   76,   77,    0,    0,
       73,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   57,   58,   59,    0,    0,   55,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   29,   30,   31,    0,    0,   27,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,   11,
        0,    0,    0,    0,    0,    0,    0,   60,    0,   61,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   42,
        0,   43,    0,    0,    0,    0,    0,    0,    0,    0,
       78,    0,    0,    0,    0,    0,    4,    0,    0,    6,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   19,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   80,    0,    0,    0,    0,    0,    2,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   81,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   63,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   45,    0,   79,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   16,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   68,    0,    0,    0,    0,    0,

        0,    0,   50,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    8,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   67,   69,    0,    0,    0,
        0,    0,    0,    0,   49,   51,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   10,   12,   20,   15,
        0,    0,   72,    0,    0,    0,   54,    0,    0,    0,
        0,    0,    0,   26,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   21,    0

    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    4,    1,    1,    1,    5,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    6,    1,    7,    8,    1,    9,    1,   10,
        1,    1,   11,    1,    1,   12,   13,   14,    1,    1,
       15,    1,    1,   16,    1,    1,    1,   17,    1,    1,
        1,   18,    1,    1,   19,    1,   20,   21,   22,   23,

       24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   35,   36,   37,   38,   39,   40,    1,   41,    1,
        1,    1,   42,   43,   44,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[45] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[502] =
    {   0,
        0,    5,   47,    0,    0,   12,  563,  564,  564,  564,
       85,  118,  154,    5,  192,  564,  564,  564,  564,  554,
      564,  564,   39,  539,    0,    1,  527,  539,  534,  533,
      532,  515,  520,  545,  564,  564,   44,  530,    4,   31,
      518,  530,  525,  524,  523,  506,  511,  564,  564,  564,
      564,  564,  564,  564,  564,  564,  564,  505,  515,  509,
      504,  532,  564,  564,  564,  564,  564,  564,  564,  564,
      564,  216,    5,    6,  507,   35,  505,  517,   46,  512,
      495,  510,  493,    1,   54,  564,  510,  508,  564,  564,
      495,  564,  490,  506,  490,  492,  494,  496,  485,  484,

      480,  495,  498,  564,   61,  564,  496,  494,  564,  564,
      481,  564,  476,  492,  476,  478,  480,  482,  471,  470,
      466,  481,  484,  564,  465,  472,  467,  467,   63,  564,
      478,  476,  564,  564,  564,  564,  463,  564,  460,  457,
      473,  474,  456,  458,  460,  462,  451,  450,  461,  445,
      451,  459,  462,  456,  564,  564,  564,  564,  447,  443,
      564,  455,  439,  439,  444,  444,  435,  434,  434,  433,
      446,  440,  564,  564,  564,  434,  430,  564,  442,  426,
      426,  431,  431,  422,  421,  421,  420,  433,  427,  435,
      430,  413,  426,  564,  564,  564,  417,  413,  564,  411,

      424,  408,  418,  407,  412,  412,  403,  402,  402,  420,
      400,  398,  412,  406,  396,  393,  411,  564,  392,  564,
      397,  401,  395,  407,  400,  388,  400,  383,  401,  564,
      382,  564,  387,  391,  385,  397,  390,  378,  390,  391,
      564,  373,  374,  370,  388,  374,  388,  375,  366,  564,
      371,  375,  369,  381,  367,  373,  374,  360,  372,  564,
      362,  360,  360,  372,  371,  370,  363,  351,  363,  364,
      352,  350,  350,  362,  361,  360,  353,  341,  353,  354,
      348,  564,  354,  340,  338,  334,  345,  564,  336,  348,
      347,  346,  339,  330,  326,  339,  337,  338,  320,  324,

      337,  324,  324,  322,  329,  318,  318,  311,  310,  314,
      327,  314,  314,  312,  319,  308,  308,  301,  320,  306,
      298,  302,  303,  314,  301,  301,  299,  306,  310,  294,
      308,  293,  286,  305,  293,  290,  297,  282,  295,  290,
      277,  294,  564,  296,  284,  281,  288,  273,  286,  281,
      268,  285,  564,  271,  564,  286,  274,  264,  270,  277,
      262,  275,  270,  259,  256,  263,  272,  564,   81,  274,
      268,  268,  255,  265,  110,  269,  263,  263,  250,  260,
      246,  129,  263,  257,  257,  251,  243,  239,  252,  247,
      234,  236,  244,   87,  564,  233,  232,  241,  228,  230,

      238,  139,  564,  227,  226,  229,  234,  229,  220,  239,
      221,  229,  143,  564,  230,  217,  227,  214,  229,  216,
      220,  219,  222,  206,  208,  564,  564,  218,  206,  210,
      209,  212,  196,  193,  564,  564,  200,  200,  201,  188,
      186,  187,  185,  188,  163,  161,  564,  564,  175,  564,
      153,  160,  155,  155,  149,  155,  150,  150,  146,  142,
      152,  148,  153,  141,  141,  141,  140,  151,  138,  136,
      146,  115,  125,  111,  106,  117,  104,   97,  107,   82,
      100,   75,   79,   83,   59,   75,   55,   54,   48,   47,
       26,   30,    9,   22,   15,   13,    8,    5,  564,  564,

        0
    } ;

static const flex_int16_t yy_def[502] =
    {   0,
      501,  501,  501,    3,    3,    3,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,

      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,

      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,

      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,

      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,    0,

      500
    } ;

static const flex_int16_t yy_nxt[609] =
    {   0,
        8,    9,   10,   11,    8,   12,    9,   10,   11,  500,
       12,   57,  500,  500,  500,  500,    8,   13,  500,   93,
      154,  500,   13,  113,   58,  140,  138,   94,   95,   59,
      499,  114,   60,  141,  155,  498,  133,   96,  109,   61,
       97,   18,   14,   19,  139,   89,  497,   14,    9,   10,
       11,   15,   12,   18,   86,   19,  199,  496,  115,  106,
       87,   88,  143,   89,   13,  107,  108,  116,  109,  148,
      117,  144,   90,  178,  145,  156,   91,  110,  157,  495,
      161,  111,  173,  149,  194,  174,  494,  195,   16,   14,
       17,   20,  158,  493,   21,   21,   21,  492,   21,  175,

       22,  196,  491,  390,   23,  391,   24,   25,  423,   26,
       57,  424,   27,  490,  392,   28,   29,   30,  393,  489,
      488,   31,   32,   33,   34,  425,  487,   35,   35,   35,
      486,   35,  398,   36,  399,  195,  485,   37,  484,   38,
       39,  134,   40,  400,  483,   41,  174,  401,   42,   43,
       44,  407,  408,  409,   45,   46,   47,   48,   49,   50,
      432,  410,  411,  433,  444,  482,  412,  445,  481,  157,
      480,   51,  479,  478,  477,  476,  135,  434,  475,  474,
      130,  446,  473,  472,  471,  470,   52,  106,  469,  468,
      467,   86,   53,  466,  196,   54,   55,   56,   62,  465,

       63,   64,   65,   66,   67,   68,   69,   70,   71,  194,
      464,   72,  136,   73,   74,   75,   76,  463,  462,   77,
      461,  460,   78,   79,   80,  459,  175,   81,   82,   83,
       84,  130,  458,  173,  457,  110,  456,  131,  132,  455,
      133,  158,  454,  156,  453,   90,  452,  134,  135,  136,
      451,  450,  449,  137,  448,  447,  443,  442,  441,  440,
      439,  438,  437,  436,  435,  431,  430,  429,  428,  427,
      426,  422,  421,  420,  419,  418,  417,  416,  415,  414,
       64,  413,  406,  405,  404,  403,   35,  402,  397,  396,
      395,   21,  394,  389,  388,  387,  386,  385,   66,   65,

       68,  384,   63,  383,  382,  381,  380,  379,  378,   35,
       35,   35,  377,  376,  375,  374,  373,  372,   21,   21,
       21,  371,  370,  369,  368,  367,  366,  365,  364,  363,
      362,  361,  360,  359,  358,  357,  356,  355,  354,  353,
      352,  351,  350,  349,  348,  347,  346,  345,  344,  343,
      342,  341,  340,  339,  338,  337,  336,  335,  334,  333,
      332,  331,  330,  329,  328,  327,  326,  325,  324,  323,
       71,  322,  321,  320,  319,  318,  317,  316,  315,  314,
      313,  312,  311,  310,  309,  308,  307,  306,  305,  304,
      303,  302,  301,  300,  299,  298,  297,  296,  295,  294,

      293,  292,  291,  290,  289,  288,  287,  286,  285,  284,
      283,  282,  281,  280,  279,  278,  277,  276,  275,  274,
      273,  272,  271,  270,  269,  268,  267,  266,  265,  264,
      263,  262,  261,  260,  259,  258,  257,  256,  255,  254,
      253,  252,  251,  250,  249,  248,   70,  247,  246,  245,
      244,  243,  242,  241,  240,  239,  238,  237,  236,  235,
      234,  233,  232,  231,   36,  230,  229,  228,  227,  226,
      225,  224,  223,  222,  221,  220,  219,   22,  218,  217,
      216,  215,  214,  213,  212,  211,  210,  209,  208,  207,
      206,  205,  204,  203,  202,  201,  200,  199,  198,  197,

      193,  192,  191,  190,  189,  188,  187,  186,  185,  184,
      183,  182,  181,  180,  179,  178,  177,  176,  172,  171,
      170,  169,  168,  167,  166,  165,  164,  163,  162,  161,
      160,  159,  153,  152,  151,  150,  147,  146,  142,  129,
      128,  127,  126,  125,  124,  123,  122,  121,  120,  119,
      118,  112,  105,  104,  103,  102,  101,  100,   99,   98,
       92,   85,  500,    7,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,

      500,  500,  500,  500,  500,  500,  500,  500
    } ;

static const flex_int16_t yy_chk[609] =
    {   0,
      501,    1,    1,    1,    5,    1,    2,    2,    2,    0,
        2,   14,    0,    0,    0,    0,    6,    1,    0,   25,
       84,    0,    2,   39,   14,   74,   73,   25,   26,   14,
      498,   39,   14,   74,   84,  497,  496,   26,  495,   14,
       26,    5,    1,    5,   73,  494,  493,    2,    3,    3,
        3,    3,    3,    6,   23,    6,  492,  491,   40,   37,
       23,   23,   76,   23,    3,   37,   37,   40,   37,   79,
       40,   76,   23,  490,   76,   85,   23,   37,   85,  489,
      488,   37,  105,   79,  129,  105,  487,  129,    3,    3,
        3,   11,   85,  486,   11,   11,   11,  485,   11,  105,

       11,  129,  484,  369,   11,  369,   11,   11,  394,   11,
      483,  394,   11,  482,  369,   11,   11,   11,  369,  481,
      480,   11,   11,   11,   12,  394,  479,   12,   12,   12,
      478,   12,  375,   12,  375,  477,  476,   12,  475,   12,
       12,  474,   12,  375,  473,   12,  472,  375,   12,   12,
       12,  382,  382,  382,   12,   12,   12,   13,   13,   13,
      402,  382,  382,  402,  413,  471,  382,  413,  470,  469,
      468,   13,  467,  466,  465,  464,  463,  402,  462,  461,
      460,  413,  459,  458,  457,  456,   13,  455,  454,  453,
      452,  451,   13,  449,  446,   13,   13,   13,   15,  445,

       15,   15,   15,   15,   15,   15,   15,   15,   15,  444,
      443,   15,  442,   15,   15,   15,   15,  441,  440,   15,
      439,  438,   15,   15,   15,  437,  434,   15,   15,   15,
       15,   72,  433,  432,  431,  430,  429,   72,   72,  428,
       72,  425,  424,  423,  422,  421,  420,   72,   72,   72,
      419,  418,  417,   72,  416,  415,  412,  411,  410,  409,
      408,  407,  406,  405,  404,  401,  400,  399,  398,  397,
      396,  393,  392,  391,  390,  389,  388,  387,  386,  385,
      384,  383,  381,  380,  379,  378,  377,  376,  374,  373,
      372,  371,  370,  367,  366,  365,  364,  363,  362,  361,

      360,  359,  358,  357,  356,  354,  352,  351,  350,  349,
      348,  347,  346,  345,  344,  342,  341,  340,  339,  338,
      337,  336,  335,  334,  333,  332,  331,  330,  329,  328,
      327,  326,  325,  324,  323,  322,  321,  320,  319,  318,
      317,  316,  315,  314,  313,  312,  311,  310,  309,  308,
      307,  306,  305,  304,  303,  302,  301,  300,  299,  298,
      297,  296,  295,  294,  293,  292,  291,  290,  289,  287,
      286,  285,  284,  283,  281,  280,  279,  278,  277,  276,
      275,  274,  273,  272,  271,  270,  269,  268,  267,  266,
      265,  264,  263,  262,  261,  259,  258,  257,  256,  255,

      254,  253,  252,  251,  249,  248,  247,  246,  245,  244,
      243,  242,  240,  239,  238,  237,  236,  235,  234,  233,
      231,  229,  228,  227,  226,  225,  224,  223,  222,  221,
      219,  217,  216,  215,  214,  213,  212,  211,  210,  209,
      208,  207,  206,  205,  204,  203,  202,  201,  200,  198,
      197,  193,  192,  191,  190,  189,  188,  187,  186,  185,
      184,  183,  182,  181,  180,  179,  177,  176,  172,  171,
      170,  169,  168,  167,  166,  165,  164,  163,  162,  160,
      159,  154,  153,  152,  151,  150,  149,  148,  147,  146,
      145,  144,  143,  142,  141,  140,  139,  137,  132,  131,

      128,  127,  126,  125,  123,  122,  121,  120,  119,  118,
      117,  116,  115,  114,  113,  111,  108,  107,  103,  102,
      101,  100,   99,   98,   97,   96,   95,   94,   93,   91,
       88,   87,   83,   82,   81,   80,   78,   77,   75,   62,
       61,   60,   59,   58,   47,   46,   45,   44,   43,   42,
       41,   38,   34,   33,   32,   31,   30,   29,   28,   27,
       24,   20,    7,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,

      500,  500,  500,  500,  500,  500,  500,  500
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "quote_fmt_lex.l"
#line 4 "quote_fmt_lex.l"
/*
 * Claws Mail -- a GTK based, lightweight, and fast e-mail client
 * Copyright (c) 1999-2007 by Hiroyuki Yamamoto & The Claws Mail Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

#include "quote_fmt_lex.h"
#include "quote_fmt_parse.h"

#line 1023 "quote_fmt_lex.c"

#line 34 "quote_fmt_lex.l"
/*
 * see notes below.
 */
int quote_fmt_firsttime = 1;
int line = -1;
int escaped_string = 0;
#line 1032 "quote_fmt_lex.c"
#line 1033 "quote_fmt_lex.c"

#define INITIAL 0
#define S_NORMAL 1
#define S_DATE 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 42 "quote_fmt_lex.l"



#line 46 "quote_fmt_lex.l"
/*
 * NOTES:
 * this lex script used to use characters also in use
 * by strftime() (which we want to use for custom
 * time formats in replies and templates). to circumvent
 * this we have to play a little bit with states.
 *
 * these are the characters we also want to use in the
 * %D time customizer:
 *
 * %a %A %b %B %c %C %d %H %I %j %m %M %p %S %w %x %y %Y %Z
 *
 * you can use these characters too, but don't forget to
 * prepend them with the <S_NORMAL> state.
 *
 * also there is also work around for resetting the state
 * (firsttime variable). this assumes that yylex() will
 * always return to S_NORMAL after quote fmt parsing is
 * done.
 */
 


	if (quote_fmt_firsttime) {
		BEGIN S_NORMAL;
		quote_fmt_firsttime = 0;
	}	


#line 1284 "quote_fmt_lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 501 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 500 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 75 "quote_fmt_lex.l"
/* cursor pos */ return SET_CURSOR_POS;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 76 "quote_fmt_lex.l"
/* email address */ return SHOW_MAIL_ADDRESS;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 77 "quote_fmt_lex.l"
/* cc */ return SHOW_CC;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 78 "quote_fmt_lex.l"
/* date */ return SHOW_DATE;
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 79 "quote_fmt_lex.l"
/* date */ { BEGIN S_DATE; return SHOW_DATE_EXPR; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 80 "quote_fmt_lex.l"
/* from */ return SHOW_FROM;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 81 "quote_fmt_lex.l"
/* first name */ return SHOW_FIRST_NAME;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 82 "quote_fmt_lex.l"
/* message-id */ return SHOW_MESSAGEID;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 83 "quote_fmt_lex.l"
/* initial of sender */ return SHOW_SENDER_INITIAL;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 84 "quote_fmt_lex.l"
/* message with no signature */ return SHOW_MESSAGE_NO_SIGNATURE;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 85 "quote_fmt_lex.l"
/* message */ return SHOW_MESSAGE;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 86 "quote_fmt_lex.l"
/* newsgroups */ return SHOW_NEWSGROUPS;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 87 "quote_fmt_lex.l"
/* full name */ return SHOW_FULLNAME;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 88 "quote_fmt_lex.l"
/* last name */ return SHOW_LAST_NAME;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 89 "quote_fmt_lex.l"
/* references */ return SHOW_REFERENCES;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 90 "quote_fmt_lex.l"
/* subject */ return SHOW_SUBJECT;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 91 "quote_fmt_lex.l"
/* to */ return SHOW_TO;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 92 "quote_fmt_lex.l"
/* current dictionary */ return SHOW_DICT;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 93 "quote_fmt_lex.l"
/* tags */ return SHOW_TAGS;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 94 "quote_fmt_lex.l"
/* quoted message */ return SHOW_QUOTED_MESSAGE;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 95 "quote_fmt_lex.l"
/* quoted message with no signature */ return SHOW_QUOTED_MESSAGE_NO_SIGNATURE;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 96 "quote_fmt_lex.l"
/* full name in compose account */ return SHOW_ACCOUNT_FULL_NAME;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 97 "quote_fmt_lex.l"
/* mail address in compose account */ return SHOW_ACCOUNT_MAIL_ADDRESS;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 98 "quote_fmt_lex.l"
/* compose account name itself */ return SHOW_ACCOUNT_NAME;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 99 "quote_fmt_lex.l"
/* organization in compose account */ return SHOW_ACCOUNT_ORGANIZATION;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 100 "quote_fmt_lex.l"
/* signature in compose account */ return SHOW_ACCOUNT_SIG;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 101 "quote_fmt_lex.l"
/* signature path in compose account */ return SHOW_ACCOUNT_SIGPATH;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 102 "quote_fmt_lex.l"
/* main dict (if enabled) in compose account */ return SHOW_ACCOUNT_DICT;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 103 "quote_fmt_lex.l"
/* completion of 'Cc' from the address book */ return SHOW_ADDRESSBOOK_COMPLETION_FOR_CC;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 104 "quote_fmt_lex.l"
/* completion of 'From' from the address book */ return SHOW_ADDRESSBOOK_COMPLETION_FOR_FROM;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 105 "quote_fmt_lex.l"
/* completion of 'To' from the address book */ return SHOW_ADDRESSBOOK_COMPLETION_FOR_TO;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 106 "quote_fmt_lex.l"
/* % */ return SHOW_PERCENT;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 107 "quote_fmt_lex.l"
/* \ */ return SHOW_BACKSLASH;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 108 "quote_fmt_lex.l"
/* tab */ return SHOW_TAB;
	YY_BREAK
case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
#line 109 "quote_fmt_lex.l"
/* return */ { line++; return SHOW_EOL; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 110 "quote_fmt_lex.l"
/* escaped return */ { if (escaped_string) line++; return SHOW_EOL; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 111 "quote_fmt_lex.l"
/* ? */ return SHOW_QUESTION_MARK;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 112 "quote_fmt_lex.l"
return SHOW_EXCLAMATION_MARK;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 113 "quote_fmt_lex.l"
return SHOW_PIPE;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 114 "quote_fmt_lex.l"
return SHOW_OPARENT;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 115 "quote_fmt_lex.l"
return SHOW_CPARENT;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 116 "quote_fmt_lex.l"
/* query date */ return QUERY_DATE;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 117 "quote_fmt_lex.l"
/* query from */ return QUERY_FROM;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 118 "quote_fmt_lex.l"
/* query from name */ return QUERY_FULLNAME;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 119 "quote_fmt_lex.l"
/* query subject */ return QUERY_SUBJECT;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 120 "quote_fmt_lex.l"
/* query to */ return QUERY_TO;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 121 "quote_fmt_lex.l"
/* query current dictionary set and enabled */ return QUERY_DICT;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 122 "quote_fmt_lex.l"
/* query cc */ return QUERY_CC;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 123 "quote_fmt_lex.l"
/* query newsgroups */ return QUERY_NEWSGROUPS;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 124 "quote_fmt_lex.l"
/* query message-id */ return QUERY_MESSAGEID;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 125 "quote_fmt_lex.l"
/* query references */ return QUERY_REFERENCES;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 126 "quote_fmt_lex.l"
/* query full name in compose account */ return QUERY_ACCOUNT_FULL_NAME;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 127 "quote_fmt_lex.l"
/* query organization in compose account */ return QUERY_ACCOUNT_ORGANIZATION;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 128 "quote_fmt_lex.l"
/* query signature */ return QUERY_ACCOUNT_SIG;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 129 "quote_fmt_lex.l"
/* query signature path */ return QUERY_ACCOUNT_SIGPATH;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 130 "quote_fmt_lex.l"
/* query account main dict enabled */ return QUERY_ACCOUNT_DICT;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 131 "quote_fmt_lex.l"
/* query completion for 'Cc' in address book */ return QUERY_CC_FOUND_IN_ADDRESSBOOK;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 132 "quote_fmt_lex.l"
/* query completion for 'From' in address book */ return QUERY_FROM_FOUND_IN_ADDRESSBOOK;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 133 "quote_fmt_lex.l"
/* query completion for 'To' in address book */ return QUERY_TO_FOUND_IN_ADDRESSBOOK;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 134 "quote_fmt_lex.l"
/* query not(date) */ return QUERY_NOT_DATE;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 135 "quote_fmt_lex.l"
/* query not(from) */ return QUERY_NOT_FROM;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 136 "quote_fmt_lex.l"
/* query not(from name) */ return QUERY_NOT_FULLNAME;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 137 "quote_fmt_lex.l"
/* query not(subject) */ return QUERY_NOT_SUBJECT;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 138 "quote_fmt_lex.l"
/* query not(to) */ return QUERY_NOT_TO;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 139 "quote_fmt_lex.l"
/* query not(current dictionary set and enabled) */ return QUERY_NOT_DICT;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 140 "quote_fmt_lex.l"
/* query not(cc) */ return QUERY_NOT_CC;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 141 "quote_fmt_lex.l"
/* query not(newsgroups) */ return QUERY_NOT_NEWSGROUPS;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 142 "quote_fmt_lex.l"
/* query not(message-id) */ return QUERY_NOT_MESSAGEID;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 143 "quote_fmt_lex.l"
/* query not(references) */ return QUERY_NOT_REFERENCES;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 144 "quote_fmt_lex.l"
/* query not(full name in compose account) */ return QUERY_NOT_ACCOUNT_FULL_NAME;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 145 "quote_fmt_lex.l"
/* query not(organization in compose account) */ return QUERY_NOT_ACCOUNT_ORGANIZATION;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 146 "quote_fmt_lex.l"
/* query not(signature) */ return QUERY_NOT_ACCOUNT_SIG;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 147 "quote_fmt_lex.l"
/* query not(signature path) */ return QUERY_NOT_ACCOUNT_SIGPATH;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 148 "quote_fmt_lex.l"
/* query not(account main dict enabled and set) */ return QUERY_NOT_ACCOUNT_DICT;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 149 "quote_fmt_lex.l"
/* query not(completion for 'Cc' in address book) */ return QUERY_NOT_CC_FOUND_IN_ADDRESSBOOK;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 150 "quote_fmt_lex.l"
/* query not(completion for 'From' in address book) */ return QUERY_NOT_FROM_FOUND_IN_ADDRESSBOOK;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 151 "quote_fmt_lex.l"
/* query not(completion for 'To' in address book) */ return QUERY_NOT_TO_FOUND_IN_ADDRESSBOOK;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 152 "quote_fmt_lex.l"
/* insert file */ return INSERT_FILE;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 153 "quote_fmt_lex.l"
/* insert program output */ return INSERT_PROGRAMOUTPUT;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 154 "quote_fmt_lex.l"
/* insert user input */ return INSERT_USERINPUT;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 155 "quote_fmt_lex.l"
/* attach file */ return ATTACH_FILE;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 156 "quote_fmt_lex.l"
/*  file whose name's got from program output */ return ATTACH_PROGRAMOUTPUT;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 157 "quote_fmt_lex.l"
return OPARENT;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 158 "quote_fmt_lex.l"
{ BEGIN S_NORMAL; return CPARENT; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 159 "quote_fmt_lex.l"
return OPARENT;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 160 "quote_fmt_lex.l"
return CPARENT;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 161 "quote_fmt_lex.l"
{ yylval.chr = yytext[0]; return CHARACTER; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 163 "quote_fmt_lex.l"
ECHO;
	YY_BREAK
#line 1778 "quote_fmt_lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(S_NORMAL):
case YY_STATE_EOF(S_DATE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 501 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 501 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 500);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 163 "quote_fmt_lex.l"


